ete2.phylomedb

Package ete2 :: Package phylomedb |
[hide private]
[frames] | no frames]

# Package phylomedb

source code

Submodules | [hide private]
ete2.phylomedb.phylomeDB

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev90``'``
| species_ages = ``{``'``human_phylome``'``:` `{``'``Aga``'``:` 8`,` `'``Ago``'``:` 9`,` `'``Ame``'``:` 8`...``
| _humanv1 = ``{``'``Aga``'``:` 8`,` `'``Ago``'``:` 9`,` `'``Ame``'``:` 8`,` `'``Ath``'``:` 10`,` `'``Bta``'``:` 3`,``...``
| __package__ = `None`

Variables Details | [hide private]

  ### species_ages Value:
      {'human_phylome': {'Aga': 8,
                         'Ago': 9,
                         'Ame': 8,
                         'Ath': 10,
                         'Bta': 3,
                         'Cal': 9,
                         'Cbr': 8,
                         'Cel': 8,
      ...

  ### _humanv1 Value:
      {'Aga': 8,
       'Ago': 9,
       'Ame': 8,
       'Ath': 10,
       'Bta': 3,
       'Cal': 9,
       'Cbr': 8,
       'Cel': 8,
      ...